﻿using System;
using Steema.TeeChart;
using Steema.TeeChart.Styles;
using UIKit;
using System.Drawing;

namespace SteemaTest
{
	public partial class ViewController : UIViewController
	{
		protected ViewController(IntPtr handle) : base(handle)
		{
			// Note: this .ctor should not contain any initialization logic.
		}
		TChart tChart;
		public override void ViewDidLoad()
		{
			base.ViewDidLoad();
			// Perform any additional setup after loading the view, typically from a nib.


			tChart = new TChart();
			tChart.Frame = new CoreGraphics.CGRect(View.Bounds.X, View.Bounds.Y, 600, View.Bounds.Height);
			tChart.Aspect.View3D = false;
			tChart.Legend.Transparent = true;
			tChart.Legend.Visible = false;
			tChart.Header.Visible = false;
			tChart.Panning.Active = true;
			tChart.Panning.Allow = ScrollModes.Horizontal;
			tChart.Zoom.Allow = false;

			//-------PANEL-------//
			var panel = tChart.Panel;
			panel.MarginLeft = 0;
			panel.MarginRight = 0;
			panel.MarginTop = 5;
			panel.MarginBottom = 5;
			panel.Gradient.Visible = false;


			// ----BOTTOM AXIS-----//
			var bottomAxis = tChart.Axes.Bottom;
			bottomAxis.Automatic = true;
			bottomAxis.Ticks.Length = 1;
			bottomAxis.RelativePosition = 0;
			bottomAxis.MinorGrid.Visible = false;
			bottomAxis.MinorTicks.Visible = false;
			bottomAxis.Grid.Visible = false;
			bottomAxis.Labels.DateTimeFormat = "HH:mm";
			//bottomAxis.SetMinMax(chartCfg.StartDate, chartCfg.EndDate);
			bottomAxis.Increment = Steema.TeeChart.Utils.GetDateTimeStep(Steema.TeeChart.DateTimeSteps.SixHours);


			// ------LEFT AXIS----------------//
			var leftAxis = tChart.Axes.Left;

			leftAxis.Automatic = true;
			leftAxis.RelativePosition = 0;
			leftAxis.MinorGrid.Visible = false;
			leftAxis.MinorTicks.Visible = false;
			leftAxis.Grid.Visible = false;
			leftAxis.Visible = true;

			View.AddSubview(tChart);
			tChart.AutoresizingMask = UIViewAutoresizing.FlexibleHeight | UIViewAutoresizing.FlexibleWidth;
			View.ClipsToBounds = true;
			View.SetNeedsDisplay();

			AddSeries();
			tChart.BeforeDrawSeries += Chart_BeforeDrawSeries;
		}

		private void Chart_BeforeDrawSeries(object sender, Steema.TeeChart.Drawing.Graphics3D g)
		{
			//doesnt work - rectangle moves around screen randomly
			// how to add two rectangles also?
			var tmpHour = Utils.GetDateTimeStep(DateTimeSteps.OneHour);

			Rectangle rect = tChart.Chart.ChartRect;
			g.BackColor = Color.Red;


			DateTime dtSunset = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 18, 0, 0);
			g.Rectangle(rect.Top + 60, tChart.Axes.Bottom.CalcXPosValue(dtSunset.ToOADate()), tChart.Axes.Bottom.CalcXPosValue(dtSunset.ToOADate() + tmpHour * 12), rect.Bottom - 60);
		}
		
		void AddSeries()
		{
			
			var c = tChart.Series.Count;
			var line = new Line(tChart.Chart);
			Series series = tChart.Series[0];

			series.Add(DateTime.Now, 1);
			series.Add(DateTime.Now.AddHours(6), 5);
			series.Add(DateTime.Now.AddHours(12), 9);
			series.Add(DateTime.Now.AddHours(24), 3);
			series.Add(DateTime.Now.AddHours(30), 9);
			series.Add(DateTime.Now.AddHours(36), 8);
			series.Add(DateTime.Now.AddHours(42), 4);
			series.Add(DateTime.Now.AddHours(48), 1);





		
		}
		public override void DidReceiveMemoryWarning()
		{
			base.DidReceiveMemoryWarning();
			// Release any cached data, images, etc that aren't in use.
		}
	}
}
